#
# spec file for package link-grammar
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           link-grammar
Version:        5.0.8
Release:        6.4
Summary:        An English grammar checker
License:        BSD-3-Clause
Group:          Productivity/Text/Spell
Url:            http://www.abisource.com/projects/link-grammar/
Source:         http://www.abisource.com/downloads/link-grammar/5.0.8/%{name}-%{version}.tar.gz
BuildRequires:  aspell-devel
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  libedit-devel
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The Link Grammar Parser is a syntactic parser of English, based on link
grammar, an original theory of English syntax. Given a sentence, the
system assigns to it a syntactic structure, which consists of a set of
labeled links connecting pairs of words. The parser also produces a
"constituent" (Penn tree-bank style phrase tree) representation of a
sentence (showing noun phrases, verb phrases, etc.).

%package -n  perl-clinkgrammar
Summary:        An English grammar checker (Perl bindings)
Group:          Development/Libraries/C and C++

%description -n  perl-clinkgrammar
The Link Grammar Parser is a syntactic parser of English, based on link
grammar, an original theory of English syntax. Given a sentence, the
system assigns to it a syntactic structure, which consists of a set of
labeled links connecting pairs of words. The parser also produces a
"constituent" (Penn tree-bank style phrase tree) representation of a
sentence (showing noun phrases, verb phrases, etc.).

%package devel
Summary:        An English grammar checker (Development files)
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       perl-clinkgrammar = %{version}

%description devel
The Link Grammar Parser is a syntactic parser of English, based on link
grammar, an original theory of English syntax. Given a sentence, the
system assigns to it a syntactic structure, which consists of a set of
labeled links connecting pairs of words. The parser also produces a
"constituent" (Penn tree-bank style phrase tree) representation of a
sentence (showing noun phrases, verb phrases, etc.).

This package contains the development files.

%prep
%setup -q
# Install perl bindings to vendorlib, not sitelib
sed -i "s:sitearchexp:vendorarchexp:g" configure*

%build
# --enable-sat-solver and --enable-corpus-stats are still at the prototype stage
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name '*.la' -delete -print

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%clean
rm -rf %{buildroot}

%files
%defattr(-, root, root)
%doc AUTHORS ChangeLog LICENSE MAINTAINERS README TODO
%{_bindir}/*
%{_libdir}/*.so.*
%{_datadir}/link-grammar
%{_mandir}/man1/*

%files -n perl-clinkgrammar
%defattr(-,root,root)
%{perl_vendorlib}/*/clinkgrammar.pm
%{perl_vendorlib}/*/clinkgrammar.so.*

%files devel
%defattr(-, root, root)
%dir %{_includedir}/link-grammar
%{_includedir}/link-grammar/*.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{perl_vendorlib}/*/clinkgrammar.so

%changelog
* Tue Jul  1 2014 dimstar@opensuse.org
- Update to version 5.0.8:
  + Fix handling of initial letters in ordered lists.
  + Fix another serious error in constituent printing, introduced
    in 4.8.0.
  + New emoticon support was clobbering certain number expressions.
  + Misc English dict fixes, more verb-wall connectors.
- Changes from version 5.0.7:
  + Compile fixes in SAT solver.
  + Add missing verb-wall connectors for is, hasn't, haven't,
    hadn't, etc.
  + Remove verb-wall connector for imperative verbs.
  + Fix serious error in constituent printing, introduced in 5.0.3.
  + Fix old bug in command-line handling of options.
  + Fix parsing of various ordered lists, including some tables of
    contents.
- Ensure perl bindings are installed in vendorlib instead of
  sitelib (by replacnig the perl calls using sed in configure).
- Create new subpackage perl-clinkgrammar; require the same from
  the -devel package.
* Thu Apr 24 2014 dimstar@opensuse.org
- Update to version 5.0.6:
  + Fix: JSON output format missing brace.
  + Fix: serious error in Russian morphology printing.
- Changes from version 5.0.5:
  + Fix packaging bug with the English dictionary.
* Thu Apr 17 2014 dimstar@opensuse.org
- Update to version 5.0.4:
  + Expanded unit tests for capitalization.
  + Fix who questions: "Who are they?", "Who are you?", etc.
  + Provide verb-wall linkage for many questions.
  + Add Biblical naming idioms: "Lud, son of Shem, ...".
  + Fix MacOSX build break.
  + Fix the 'make clean' target to not remove critical files.
  + Fix broken emoticon support in English dict.
  + Remove obsolete entity detection tokens from Englsh dict.
  + Fix broken equation parsing.
- Changes from version 5.0.3:
  + Minor memory usage optimization
  + Fix unit test: suppress printing of empty word, and of
    morphology.
  + Fix: Swig and python were meant to be optional, not required!
- Changes from version 5.0.2:
  + Expanded unit tests.
  + Fix another sqlite3-dev build break.
- Changes from version 5.0.1:
  + Dictionary debugging print fixes.
  + Print summary of parse statistics when in batch mode.
  + Generalize the notion of prefix/suffix to arbitrary classes.
  + Fixes for German adjectives.
  + Fix build break when sqlite3-dev not installed.
  + Fix regression in Russian morphology handling.
- Add gcc-c++ BuildRequires: new dependency.
* Wed Apr  2 2014 dimstar@opensuse.org
- Update to version 5.0.0:
  + License upgrade to LGPLv2.1.
  + Arabic dictionaries, from Jon Dehdari
  + Persian dictionaries, from Jon Dehdari
  + Support for Hebrew tokenization, from Amir P.
  + Fix wild-card matching for user-supplied word lookup.
  + Prototype Turkish dictionary from Can Bruce.
  + Re-arrange programming language bindings directory.
  + Adopt the orphaned/unsupported pylinkgrammar Python bindings.
  + Deprecate the obsolete CNode interface.
  + Provide low-level perl bindings.
  + Adopt the orphaned/unsupported Ocaml bindings.
  + Support affirmative replies: "Who did it?" "John's evil twin."
  + Expanded Lithuanian dictionary.
  + Minor disjunct printing fixes.
  + Fix: "Mary is too XXX to talk to."
  + Prototype Hebrew dictionary from Amir P.
  + Change !suffixes flag to !morphology.
  + Introduce a bi-directional connector, for free-word-order
    languages.
  + Introduce a symmetric-AND operator, for free-word-order
    languages.
  + Add demo shell script for running the JSON parse server.
  + Bugfix: Java server failing when input sentence has commas in
    it!
  + New !test and !debug commands for selective debugging support.
  + Print post-processing rejection message, when !bad is enabled.
  + Remove some deprecated functions for C API.
  + Remove all deprecated functions from Java API.
  + Initial support for an SQL-backed dynamic dictionary.
* Mon Feb  3 2014 zaitor@opensuse.org
- Update to version 4.8.6:
  + Fix minor OSX compiler warnings.
  + Check for presence of Java ant before assuming it is there.
  + Fix crash on certain sentences containing equals sign.
  + Fix parsing of lists (blah, blah and blah).
  + Fix build break for uClibc systems (Gentoo).
  + Allow ungrammatical usage of 'ages' instead of 'aged'.
  + Fix crash on certain sentences containing words with periods.
* Fri Jan 24 2014 zaitor@opensuse.org
- Update to version 4.8.5:
  + Update memory usage accounting; fix accounting bugs.
  + Fix Java garbage collection bug.
  + Fix numerous compiler warnings in the SAT-solver code.
  + Fix build-break involving multiple declaration of 'Boolean'.
- Changes from version 4.8.4:
  + Fix build break for Mac OSX.
- Changes from version 4.8.3:
  + Create new msvc12 build files, restore old msvc9 files.
  + Revert location of the Windows mbrtowc declaration.
  + Add verb-wall connector for present participles.
  + Fix build-time include file directory paths.
  + Provide the 'any' language to enumerate all possible linkages.
  + Fix recognition of U+00A0, c2 a0, NO-BREAK SPACE as whitespace.
  + Improve parse-time performance of exceptionally long sentences.
  + Fix crash on certain sentences containing equals sign.
* Sat Dec 14 2013 dimstar@opensuse.org
- Update to version 4.8.2:
  + More windows UTF-8/multi-byte fixes (for Russian).
  + Add missing JSONUtils file.
- Changes from version 4.8.1:
  + Ongoing work on viterbi.
  + Updated MSVC9 project files.
  + Fix important bug in Java services: return top parses, not
    random ones.
  + Java: for the link-diagram string, do not limit to 80 char term
    width.
  + Windows: UTF-8 fixes so that Russian works in most windows
    locales.
* Fri Oct 25 2013 zaitor@opensuse.org
- Update to version 4.8.0:
  + Support bulleted, numbered lists.
  + New link types from Lian Ruiting, for identifying the
    head-verb.
  + C API: remove some deprecated functions.
  + Java:
  - Fix bug when totalling WordNet word-sense score.
  - Add info to README about using the JSON parse server.
  - Remove many deprecated functions.
  - Fix silent failure when library is not found.
  - Add support for fetching the ASCII-art diagram string.
  - Fix insane language selection initialization.
  + Fixed:
  - "The pig runs SLOWER than the cat."
  - Conjoined superlatives: "... the longest and the farthest."
  - "inside" can be used with conjunction: "near or inside..."
  - Conjoined question modifiers: "exactly when and precisely
    where..."
  - issue 59: crash/corruption when dictionary opened twice.
  - Assorted exclamations.
  - "he answered yes".
* Sat Jun 22 2013 dimstar@opensuse.org
- Update to version 4.7.14:
  + Fix build break on MacOSX.
- Changes from version 4.7.13:
  + Remove trailing carriage return in MSVC6 filenames.
  + Performance improvement: avoid excess system timer calls.
  + Unicode fixes for Windows.
  + Fix: "... a purseful of pesos"; other currency fixes.
  + MinGW, unicode fixes.
* Mon May 27 2013 dimstar@opensuse.org
- Update to version 4.7.12:
  + Large fixes to the Russian dictionaries.
  + Windows: Explicitly fail if cygwin version is too old.
  + Tweak the lt dict to work again with the modern parser.
  + Make the fat linkages code be compile-time configurable.
  + Disable fat linkages by default; mark as deprecated.
  + Fix SAT-solver build; recent changes had broken it.
  + Export read-dict.h as a public API.
  + Ongoing development of the Viterbi prototype.
  + Windows: some UTF8/widechar refactoring.
  + Java bindings: add method to set the language.
  + CMake: add version checking to the CMakefile.
  + Fix: failed handling of capitalized first word for Russian.
  + Fix: stemming failures in many cases.
  + Add flag to suppress stem-suffix printing.
  + Windows: Fixes to MSVC6 build files.
  + Fix: hash-table bug affecting Russian dictionaries.
* Sun Mar 24 2013 dimstar@opensuse.org
- Update to version 4.7.11:
  + Fix build bug introduced recently.
  + MSVC6 build environment fixes.
  + Ongoing development of the Viterbi prototype.
* Tue Mar 12 2013 dimstar@opensuse.org
- Update to version 4.7.10:
  + New: Russian dictionaries.
  + Improve prefix, suffix handling and stemming.
  + Fix: add "gurgle.n" to dictionary.
  + Improve memory utilization (remove pointless malloc/free).
  + Fix: UTF8 multi-byte diagram printing.
  + Add UTF8 multi-byte editline support, when available.
  + Include Common Lisp bindings.
  + Ongoing work on pre-alpha Viterbi decoder.
  + Fix: Bug 55: aspell header file included even if disabled.
  + Updated MSVC6, MSVC9 project files.
  + New, improved search for java jni.h.
  + Faster counting of disjuncts for the !! command.
  + The !! command now shows regex entries and stem+suffix splits.
* Tue Nov  6 2012 dimstar@opensuse.org
- Update to version 4.7.9:
  + Fix: Poor comma chocies: "The man, that you saw...".
  + Fix: Add more java jni.h search paths.
  + Fix: Warning in java JSON interface.
  + Fix: weren't constructions: "If it weren't for Sally, ..."
  + Fix: Better support for ellipsis ...
  + Fix: strangely: "He is behaving very strangely"
  + Fix: assorted usages of yes, no, maybe
  + Fix: "being" in subordinate clauses: "The blade being dull,
    he ..."
  + Fix: Build failure for Mac OSX.
  + Fix: "... this time for real".
  + Fix: "... the impudence to laugh."
  + Fix: "we two", "us two"
  + Fix: very old parse bug, using "enough"
  + Fix: assorted profanity as synonyms to "else"
  + Fix: whoever, whomever
  + Fix: decade possessives: "It's a 60's hit"
  + Fix: "... chances that ... could be ..."
  + Fix: "Do you have it ready?"
  + Fix: "What John wants are those cats"
  + Fix: greetings
  + Fix: misc verbs: wave, ink, kiss, bake, corral, crown, decant,
    rope, slice, ink, butter, proclaim, make, give, bid, bade,
    think
  + Fix: titles can behave as indefinite nouns.
  + Fix: somewhere, near, nearby, halfway, about.
  + Fix: police-interrogation style questions.
* Sat Oct 13 2012 zaitor@opensuse.org
- Drop hunspell-devel BuildRequires, as it is not used anyway.
- Drop hack for a obsolete openSUSE version, not needed anymore.
* Thu Oct 11 2012 dimstar@opensuse.org
- Update to version 4.7.8:
  + Ongoing work on pre-alpha Viterbi decoder.
  + Fix include file paths so that 'make install' doesn't cause
    recompile.
  + Fix build break due to bad include file paths in Makefiles.
* Wed Oct 10 2012 dimstar@opensuse.org
- Update to version 4.7.7:
  + Fix configure to not bomb if c++ is not found.
  + Fix configure to explicitly require c++ only if sat-solver
    enabled.
  + Dictionary: parse comma in "Monsters, Inc."
  + Update README about Viterbi algo.
  + Update MSVC6 project file.
  + Use enums for constituent display style.
  + Move command-line parser to its own directory.
  + Portability fixes for Windows.
  + Fix: "Show results from today"
  + Fix: conjoined imperatives.
  + Fix: qualified conditional clauses
  + Fix: conjoined irregular verbs: seem, appear, do, be, prove,
    have
  + Disable fat link code via conditional compile.
  + Fix: "a lot of", "a gaggle of" now treated as quantifying
    determiners
  + Fix: likewise: "gallons of", "grams of" volume measures as
    determiners
  + Update German dictionary so that it actually loads.
  + Fix: assorted "but not", "not very" constructions.
  + Pre-alpha implementation of Viterbi decoder started.
  + Fix: conjunctions of optionally ditransitive verbs.
* Sat Apr 28 2012 dimstar@opensuse.org
- Update to version 4.7.6:
  + fast-match.c: unroll recursive call into loop.
  + Fix accidental inclusion of internal header file from public
    header file.
- Drop link-grammar-install-include.patch: No longer needed, as the
  header is no longer referenced by the main header.
* Thu Apr 26 2012 vuntz@opensuse.org
- Add link-grammar-install-include.patch: install additional header
  referenced by the main header, to fix build failure in abiword.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 4.7.5:
  + Remove several duplicate given names.
  + Remove several dozen duplicated idioms.
  + Some intransitive verbs are actually transitive in rare cases.
  + Clean up misc minor compiler warnings.
  + Use enum not int for the cost-model type.
  + Update the man page to reflect actual command usage.
  + Start using -O3 optimization for another 2%% perf improvment.
  + Fix configure.in --enable/--disable flags.
  + New AM_SILENT_RULES for less noisy build.
  + Remove malloc-dbg.c from the MSVC9 project file.
- Add gcc-c++ BuildRequires: it is now needed for the build.
* Thu Jul  7 2011 vuntz@opensuse.org
- Stop using source service to download the tarball, as Factory
  will move away from this.
* Fri Apr 29 2011 dimstar@opensuse.org
- Update to version 4.7.4:
  + Dramatic speed improvement for long sentences (hash table fix).
  + Fix: crash on certain sentences, when fat-link parsing enabled.
  + Fix: fatal error introduced in last version (combinatorial
    explosion).
  + Fix: mem leak introduced in last version (combinatorial
    explosion).
  + Assorted fixes to the Boolean SAT solver.
- Changes from version 4.7.3:
  + Fix: "level" as indefinite noun: "... at knee level".
  + Enable max disjunct cost as a controllable parser parameter.
  + Don't just give up on combinatorial explosion, show something!
- Use source services: download_url, recompress and set_version.
* Fri Jan  7 2011 vuntz@opensuse.org
- Update to version 4.7.2:
  + Fix: crash on certain sentences, when fat-link parsing enabled
  + Fix: 3 corrupted nouns in words.n.1
  + Fix: minimize cpu spin if constituent processing and-list
    overflows.
* Mon Dec 13 2010 vuntz@opensuse.org
- Update to version 4.7.1:
  + Fix: dictionary: Add "x" as synonym for "times".
  + Fix: if not set, then force-set locale to UTF-8 in the java
    library.
  + Fix: "John imagines himself lost".
  + Fix: predicative adjectives w/misc verbs: "You are driving me
    crazy"
  + Fix: "judge innocent", etc.
  + Fix: many, many conjoined present tense verbs.
  + Fix: conjoined verbs with negations.
  + Fix: "to" as post-nominal modifier: "the inability to laugh"
  + Build fixes.
* Mon Sep 13 2010 dimstar@opensuse.org
- Update to version 4.7.0:
  + Fix: hunspell configuration on Fedora
  + Fix: 'turn' with adjective: "She turned him green" from
    wingedtachikoma
  + Fix: comma-conjoined modifiers: "It tastes bitter, not sweet."
  + Fix: conjoined question words: "When and where is the party?"
  + Fix: recognize short, capitalized words (Los, La, etc.).
  + Treat colon as synonym for is: "The answer: yes."
  + Fix: begin with prepositions: "It all began in Chicago."
  + Fix: "What does it come to?" and related.
  + Fix: null infinitive: "I'd like to, I want to."
  + Fix: "Because I said so."
  + Fix: "sure" as preverbal adverb: "It sure is."
  + Fix: Gerunds with determiners: "a running of the bulls"
  + SJ link for conjoined nouns/noun phrases.
  + Sort linkages according to whether fat linkage was used.
  + Add flag to enable use of fat linkage during parsing.
    (Fat links now disabled by default).
  + Add male/female gender tags to misc nouns.
  + Fix: misc optionally transitive verbs: mix, paint, boot
  + Fix: word order: "look about fearfully", "look fearfully
    about", around
  + Fix: recognize simple fractions
  + Fix: "is" with uncountable nouns: "there is blood on your
    hands"
  + Fix: Roman numeral suffixes e.g. "Henry VIII"
  + Fix: regression in dates followed by punctuation. "In the
    1950s, ..."
  + Fix: verbs drank, drunk are optionally transitive.
  + Fix: regression: "all the X", X can be plural or mass.
  + Fix: verbs paint, color may be ditranstive: "paint the car
    bright green".
* Wed Jul 28 2010 dimstar@opensuse.org
- Update to version 4.6.7:
  + Fix configure handling of --enable-hunspell
  + Fix conjoined modifier phrases: "the black and white cat
    sleeps."
  + Fix MSWindows+MingGW compilation issue.
  + Update msvc9 Microsoft Visual C 2008 project.
* Tue Mar 23 2010 dimstar@opensuse.org
- Add a hack for an error in libedit-devel's .pc file on openSUSE
  11.2. It references to link libcurses instead of libncurses.
* Fri Mar 19 2010 dimstar@opensuse.org
- Update to version 4.6.6:
  +  Minor fixes to handling of units.
  + Fix: MSWindows+Cygwin/MingGW compilation issues.
  + Use pkgconfig for editline (from Vincent Untz)
  + Fix: "I want it back."
  + Additional titular prefixes, suffixes: Maj. Ph.D.
  + Add code to detect dictionary version number.
  + Fix: MS VC missing strdup() function.
  + Add AutoIt3 bindings from JRowe
- Drop patches (included upstream):
  + link-grammar-fix-parallel-build.patch
  + link-grammar-fix-warning.patch and
  + link-grammar-libedit-pkgconfig.patch
* Thu Dec  3 2009 vuntz@opensuse.org
- Update to version 4.6.5:
  + Fix: Superlatives without preceeding determiners ("... likes
    you best")
  + Fix: Take more care in distinguishing mass and count nouns.
  + Fix: Old bug w/relative clauses: Rw+ is optional, not
    mandatory.
  + Provide tags identifying relative, superlative adjectives.
  + Remove BioLG NUMBER-AND-UNIT handling, its been superceeded.
  + Fix handling of parenthetical phrases/clauses.
  + Fix: handling of capitalized first words ending in letter "s".
  + Fix: support "filler-it" SF link for "It was reasoned that..."
  + Fix: certian WH-word constructions: "I did not know why until
    recently"
  + Fix: go: "there goes the greatest guy ever"
  + Fix: opening coordinating conjunctions: "And you can also ..."
  + Configurable Hunspell spell-checker dictionary location.
  + Fix: Misc ordinal usage.
  + Add support for aspell spell-checker.
- Changes from version 4.6.4:
  + Restore nouns starting w/letters x-z, elided in version 4.5.9
    ff.
  + Add support for single-word interjections/exclamations!
  + Fix: sometimes command line client fails to show all valid
    linkages.
  + Misc fixes: such_that, upon, acted.v
  + Fix: impersonal "be" linking to passive participle.
  + Fix: handling of capitalized first words.
  + Fix: duplication of certain parses involving transitive verbs.
- Changes from version 4.6.3:
  + Fix compilation bug on FreeBSD.
  + Fix: allow MX link to post-nominal ", to be ..., "
  + Fix: add idiom "time and again"
  + Fix: another BioLG regression in handling of possesives.
  + Fix: handling of period at end of number at end of sentence.
  + Fix: Capitalized words ending in s at start of sentence.
  + Use corpus-statistics-based ranking by default, if available.
  + Fix difficulties in build of corpus statistics module.
- Changes from version 4.6.2:
  + Fix: "come across as authoritiative".
  + Improve java location guessing in FreeBSD
  + Fix for assert triggered by long sentences.
  + Fix: long sequence of periods treated as unknown word.
  + Add informational print showing dictionary location on startup.
  + Remove duplicated {@MV+} in tend.v
  + Automatically resize the display size to fit the current window size.
  + Fix handling of punctuation at the end of a capitalized word.
  + Fix misc verbs acting as adjectival modifiers: e.g. "given", "allied"
  + Fix bug in BioLG code regarding the handling of possesives.
  + Fix a (rare) crash in sentences with many conjunctions.
  + Fix a crash involving long sequences of UTF8 punctuation marks.
- Add aspell-devel BuildRequires.
- Add link-grammar-fix-warning.patch to fix warnings.
- Add link-grammar-fix-parallel-build.patch to fix parallel build.
- Add link-grammar-libedit-pkgconfig.patch to use pkg-config to
  detect libedit flags.
* Mon Aug 31 2009 dimstar@opensuse.org
- Update to version 4.6.1:
  + Stop printing annoying warning when !vars are used.
  + Fix missing dict file units.2 problem
  + Fix compilation bug on FreeBSD.
* Sun Aug 30 2009 dimstar@opensuse.org
- Update to version 4.6.0:
  + Avoid used of bzero, add missing include directives.
  + Reclassify a number of "medical" prepostions as adverbs.
  + Add approx 100 adverbs & 300 adjectives.
  + Add approx 250 verbs.
  + Add approx 300 nouns.
  + Add misc units.
  + Add misc European connector words/patronymics.
  + Reclassify 100's of transitive verbs as optionally-transitive.
  + Add distinct tokenization step ("sentence_split") to public
    API. This last change forces the minor-version-number bump.
* Thu Aug 27 2009 dimstar@opensuse.org
- Update to version 4.5.10:
  + Be sure to link with -lm
- Changes from version 4.5.9:
  + Modify error messages to indicate that they are from
    link-grammar.
  + Add missing Java files that were forgotten last time around.
  + Add greeting to command-line client startup.
  + Print disjunct cost also, when requesting disjunct printing.
  + Add missing color names as mass nouns.
  + Fix: Reclassify musical instruments: "He plays piano"
  + Add experimental word-clustering system.
  + Add CMake build file
  + Fix: "It takes longer than that."
  + Fix: "He has done very well."
  + Fix: a dozen optionally transitive verbs (swim, kill, etc.)
  + Fix: "He's out running."
  + Fix: "suddenly" is a "manner adverb", not a clausal adverb.
  + Fix: Use Pg links to gerunds: "He feared hitting the wall."
  + Fix: assorted numerical-range bugs.
  + Fix: prep modifiers with distances: "It is a few miles out"
  + Fix: Spelled-out dates: "It started in nineteen twelve"
  + Fix: Misc date, time expression parsing e.g "Zero hour is
    here."
  + Fix: Misc words, "ordered list", "screened out"
  + Fix: Post-fixed numbers can act as determiners.
  + Fix: "We bought the last 50 ft. of cable."
  + Fix: opening directives to imperatives: "Finally, move it
    back."
  + Fix: Improved simple equation parsing support.
  + Fix: Add misc fixes from BioLG that were previously overlooked.
  + Fix: "favorite" can take determiner "a" ("a favorite place")
  + Fix: assorted clausal complements: "The emperor ordered it
    done."
  + Fix: ordinals: "First on our list is ..."
  + Fix: verb modifier "some of the time", "most places"
  + Fix: Sit, stand take modifiers: "he stood still"
* Mon Jul 20 2009 vuntz@novell.com
- Update to version 4.5.8:
  + Fix: 'than anticipated', 'than was anticipated', etc.
  + Fix: 'saw the wood'
  + Fix: sometimes commas are used as if they were semicolons.
  + Fix: 'We have quite enough work already, thank you!'
  + Fix: allow 'and' as conjunction in entity names.
  + Fix: 'I stared him down', 'They shouted him down', 'booed off'
  + Fix: 'sound him out', 'look him over'
  + Fix: 'Somewhere in the distance'
  + Stub out list of names given to both men and women, to avoid
    duplication.
  + Fix: 'I think so, too'
  + Fixes for compilation under Cygwin.
  + From Boris Iordanov: fixes to JSON java code.
  + From Boris Iordanov: new java remote client code.
  + Fix: Biological texts commonly have adj-noun-adj-noun chains
* Tue Jun  9 2009 vuntz@novell.com
- Update to version 4.5.7:
  + Fix 'make install' for windows
  + Fix multi-threaded bug when TRACK_SPACE_USAGE is defined.
  + Add './configure --enable-mudflap' just for fun...
  + Fix: "Walk tall", "Think quick"
  + Fix: "... part no. 1234-56A"
  + Fix regression from BioLG merge: "It cost $14 million."
  + Fix come/came: "The dog came running..."
  + Fix year abbreviations: "He drove a souped-up '57 Chevy"
  + Fix sit, stand: "The dog stood still"
  + Fix act up, act out: "He is acting out." "The motor is acting
    up."
  + Fix notoriously, poorly: "The store was poorly stocked".
  + Fix: "strong" can be adverb
  + Add support for recognizing basic time zones during parsing.
  + Fix: verbs acting as adjectival modifiers: "a very politicized
    deal."
  + Fix: ".. nearly so well", "...almost so well".
  + Fix financial ranges: "It will cost $10 million to $20 million
    to build."
  + Expand handling of capitalized words that appear in entity
    names.
  + Expand the list of characters that are recognized as quotes.
  + Support usage of yes, no as sentence openers.
  + Better support for directives, commands.
  + Fix: "Ash Wednesday", "Fat Tuesday", etc.
  + Fix: post-verbal adj: "she wiped the table dry"
  + Fix: wish: "she wished me a happy birthday"
* Wed May 27 2009 vuntz@novell.com
- Update to version 4.5.6:
  + Bugfix: fix non-thread-safe usage.
  + Changes to enable MinGW/Windows to compile.
  + Update of MSVC6 build files
  + Fix: pizza, fries, chopsticks.
  + Export word-sense database to Java apps.
  + Fix: "Was the man drunk or crazy or both?"
* Fri May 22 2009 vuntz@novell.com
- Update to version 4.5.5:
  + Bugfix: crash for zero-length sentences.
- Changes from version 4.5.4:
  + Fix: "sleep in":  "A bed is something you sleep in."
  + Fix: "drinking": "Let's go drinking."
  + Fix go+bare infinitive: "Let's go shop", "Let's go swim"
  + Fix: "Let's go for a swim." "Let's go for a smoke".
  + Fix: "Let's not" "Let's not go" "Let's not cry"
  + Fix: ... is <bare-infinitive>:  "All he ever does is complain."
  + Fix: "You will die young/happy/unhappy"
  + Fix: "You should exercise to stay fit."
  + Fix: "We danced 'til dawn."
  + Fix: "tell <direct-object> off": "She had told him off."
  + Bugfix: sometimes spell checker would run even if turned off.
- Changes from version 4.5.3:
  + Haste makes waste! Revert a recent 'fix'.
- Changes from version 4.5.2:
  + Use re-entrant version of mbtowc in all code.
  + Fix run-time breakage on Mac OSX and FreeBSD.
- Changes from version 4.5.1:
  + Fix Assertion failed: negative constituent length!
  + Fix build break for Mac OSX.
  + Force use of UTF-8 locale in the command-line tool.
- Changes from version 4.5.0:
  + Hack around missing SQLite3 pkgconfig on MacOS
  + Fix adverbs: 'The motor ran hot', 'the door swung wide open', etc.
  + Fix: 'at risk of breakdown', 'under threat of fire'
  + Add regular-expression-based word guessing, from BioLG project.
    This provides support for many scientific/biomedical terms.
  + Add spell-guessing for unknown words.
  + Fix UTF8 support to be correctly thread-safe.
  + BioLG: fix post-numbering: 'it started on day one'
  + BioLG: add number ranges: 'it takes 2 to 3 times the effort'
  + BioLG: assorted adverb fixes, typical of scientific prose.
  + BioLG: initiate, attach, localize etc are optionally
    transitive.
  + BioLG: allow fork, branch, splice, export, etc to take
    particles.
  + BioLG: extended use of greek letters in biomedical text.
  + BioLG: support parsing of Roman numerals.
  + BioLG: support greek-letter-number combinations.
  + Fix: 'she was singing', etc.
  + Enable WordNet word-sense identification based on syntactical
    usage.
- Changes from version 4.4.3:
  + Look at JAVA_HOME to guess location of jni.h
  + Add dictionary maintenance utility script.
  + Add prototype German dictionary.
  + Fix sentences containing measurements, lengths, speeds. etc.
  + Add 1400 new adjectives, many of scientific origin.
  + Add 250 international currencies, including special utf8
    symbols.
  + Performance optimization in sentence tokenization.
  + Add 1100 male, female given names (from Bruce Wilcox).
  + Cleanup parsing of "in-" date expressions, e.g. "in the
    1940's".
  + Cleanup of assorted compiler warnings.
  + Fix handling of special utf8 characters in dictionary.
  + Fix hang when parsing certain utf8 input strings.
  + Make sure that most strings in API are declared const char *
  + Add option to command-line client to print disjunct strings.
- Remove AutoReqProv: it's default now.
- Add hunspell-devel and libedit-devel BuildRequires, remove
  libsatsolver-devel and sqlite3-devel BuildRequires.
- Pass --enable-corpus-stats to configure.
* Thu Jan 22 2009 hfiguiere@suse.de
- Update to 4.4.2
  * See ChangeLog file for information.
- Remove link-grammar-strncat-param.diff that was upstreamed.
- Disable static. Remove *.la
- Remove libgcj-devel dependency do disable java
- Added BuildRequires for satsolver and sqlite3
* Thu Apr  3 2008 hfiguiere@suse.de
- Make rpmlint happier
* Wed Apr  2 2008 hfiguiere@suse.de
- Fix -devel package dependency
* Tue Apr  1 2008 hfiguiere@suse.de
- Initial package, version 4.3.4.
  * Needed for AbiWord 2.6.0 (bnc#374240)
